/***************************************************************************
 * Copyright 2012 by
 *  + Christian-Albrechts-University of Kiel
 *    + Department of Computer Science
 *      + Software Engineering Group 
 *  and others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package kieker.webgui.beans.session;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

import kieker.analysis.model.analysisMetaModel.MIProject;

import org.primefaces.model.DashboardColumn;
import org.primefaces.model.DashboardModel;
import org.primefaces.model.DefaultDashboardColumn;
import org.primefaces.model.DefaultDashboardModel;

/**
 * This bean contains the project of the current (session) user for the analysis cockpit.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
@ManagedBean
@SessionScoped
public class CurrentAnalysisCockpitProjectBean {

	/**
	 * This is the page used for the redirecting during setting the current project of the user.
	 */
	private static final String PAGE_ANALYSIS_COCKPIT = "AnalysisCockpit.xhtml";
	/**
	 * This is the page used for the redirecting during closing the cockpit.
	 */
	private static final String PAGE_PROJECT_OVERVIEW = "ProjectOverview.xhtml";
	/**
	 * This is the name of the stored project. It can be used as an identifier within the FS-Manager
	 */
	private String projectName;
	/**
	 * The model containing the information about the dashboard itself.
	 */
	private DashboardModel model;
	/**
	 * This is the actual model instance. It is the in-memory-model of the current (session) user.
	 */
	private MIProject project;

	/**
	 * Creates a new instance of this class.
	 */
	public CurrentAnalysisCockpitProjectBean() {
		// No code necessary

		// This code is just for test purposes
		this.model = new DefaultDashboardModel();
		final DashboardColumn column1 = new DefaultDashboardColumn();
		final DashboardColumn column2 = new DefaultDashboardColumn();

		column1.addWidget("panel1");
		column1.addWidget("panel2");

		this.model.addColumn(column1);
		this.model.addColumn(column2);
	}

	/**
	 * Delivers the model for the dashboard.
	 * 
	 * @return The stored instance of {@link DashboardModel}.
	 */
	public DashboardModel getModel() {
		return this.model;
	}

	/**
	 * Sets the new model for the dashboard.
	 * 
	 * @param model
	 *            The new dashboard model to be stored in this bean.
	 */
	public void setModel(final DashboardModel model) {
		this.model = model;
	}

	/**
	 * This method delivers the project stored in this bean.
	 * 
	 * @return The project for this user.
	 */
	public MIProject getProject() {
		synchronized (this) {
			return this.project;
		}
	}

	/**
	 * This method sets the project stored within this bean and returns the new page for the navigation.
	 * 
	 * @param name
	 *            The name of the project.
	 * @return The name of the page for the analysis view work space.
	 */
	public String setProject(final MIProject newProject, final String newName) {
		synchronized (this) {
			// Remember the given parameters
			this.project = newProject;
			this.projectName = newName;
		}

		return CurrentAnalysisCockpitProjectBean.PAGE_ANALYSIS_COCKPIT;
	}

	/**
	 * This method delivers the project name stored in this bean.
	 * 
	 * @return The project name for this user.
	 */
	public String getProjectName() {
		synchronized (this) {
			return this.projectName;
		}
	}

	/**
	 * This method clears the bean. In other words: The stored project is set to null and it will return the page of the project overview for navigation purposes.
	 * 
	 * @return The name of the page of the project overview.
	 */
	public String clearProject() {
		synchronized (this) {
			this.projectName = null; // NOPMD
			this.project = null; // NOPMD
		}

		return CurrentAnalysisCockpitProjectBean.PAGE_PROJECT_OVERVIEW;
	}
}
